@@ -3,7 +3,8 @@
 @FileName: yaml_tool.py
 @Author: chenxiaodong
 @CreatTime: 2020/9/14 16:43
-@Descriptions: 
+@Descriptions:
+This class is for yaml-file deal
 
 """
 import yaml
@@ -12,9 +13,9 @@ import yaml
 class yaml_tools:
     def __init__(self, file_path):
         """
-        :@param: file_path
-        :@return:
-
+        you should provide the file_path to use this tool
+        :param: file_path
+        :return:None
         """
         self.path = file_path
 
@@ -25,9 +26,9 @@ class yaml_tools:
 
     def get_config_by_name(self, config_name):
         """
-        :param:
-        :return:
-
+        use get method to get the String words
+        :param:config_name
+        :return:String
         """
         return self.yaml_to_json().get(config_name)
 
